function varargout = MotionAnalyst(varargin)
% MOTIONANALYST M-file for MotionAnalyst.fig
% Author:	Robb Colbrunn, Cleveland Clinic BioRobotics and Mechanical Testing Core
% Date:		2-10-10
% Last change:  2-10-10
% Version:	1.1
%      MOTIONANALYST, by itself, creates a new MOTIONANALYST or raises the existing
%      singleton*.
%
%      H = MOTIONANALYST returns the handle to a new MOTIONANALYST or the handle to
%      the existing singleton*.
%
%      MOTIONANALYST('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MOTIONANALYST.M with the given input arguments.
%
%      MOTIONANALYST('Property','Value',...) creates a new MOTIONANALYST or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before MotionAnalyst_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to MotionAnalyst_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help MotionAnalyst

% Last Modified by GUIDE v2.5 05-Jan-2010 16:50:24

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @MotionAnalyst_OpeningFcn, ...
                   'gui_OutputFcn',  @MotionAnalyst_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before MotionAnalyst is made visible.
function MotionAnalyst_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to MotionAnalyst (see VARARGIN)

% Choose default command line output for MotionAnalyst
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);
imshow('analyst.png');
% UIWAIT makes MotionAnalyst wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = MotionAnalyst_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in Track2D.
function Track2D_Callback(hObject, eventdata, handles)
% hObject    handle to Track2D (see GCBO)
MotionAnalyst2D;
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in calibration.
function calibration_Callback(hObject, eventdata, handles)
% hObject    handle to calibration (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
MotionAnalyst3D_cal;

% --- Executes on button press in Compute3D.
function Compute3D_Callback(hObject, eventdata, handles)
% hObject    handle to Compute3D (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
MotionAnalyst3D;

% --- Executes on button press in about.
function about_Callback(hObject, eventdata, handles)
MotionAnalyst_about;
% hObject    handle to about (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
